@@ -21,19 +21,19 @@
 #
 # ---------------------------------------------------------------------------##
 
-# imports
+import locale
+import os
 import re
 import sys
-import os
 import time
-import locale
 import webbrowser
-from six import print_
-
 from pickle import Pickler, Unpickler
 
 from pysollib.settings import PACKAGE, TOOLKIT
 
+import six
+from six import print_
+
 Image = ImageTk = ImageOps = None
 if TOOLKIT == 'tk':
     try:  # PIL
@@ -51,11 +51,9 @@ if TOOLKIT == 'tk':
         from PIL import PpmImagePlugin  # noqa: F401
         Image._initialized = 2
 USE_PIL = False
-if TOOLKIT == 'tk' and Image and Image.VERSION >= '1.1.7':
+if TOOLKIT == 'tk' and Image:
     USE_PIL = True
 
-if sys.version_info > (3,):
-    unicode = str
 # debug
 # Image = None
 # USE_PIL = False
@@ -158,7 +156,7 @@ if os.name == "posix":
 def win32_getusername():
     user = os.environ.get('USERNAME', '').strip()
     try:
-        user = unicode(user, locale.getpreferredencoding())
+        user = six.text_type(user, locale.getpreferredencoding())
     except Exception:
         user = ''
     return user
