@@ -21,28 +21,17 @@
 #
 # ---------------------------------------------------------------------------
 
-# imports
-import sys
-
-from six.moves import tkinter
-from . import ttk
-
-# PySol imports
-from pysollib.mygettext import _
 from pysollib.mfxutil import KwStruct
-from pysollib.wizardutil import WizardWidgets
+from pysollib.mygettext import _
 from pysollib.wizardpresets import presets
+from pysollib.wizardutil import WizardWidgets
 
-# Toolkit imports
+import six
+from six.moves import tkinter
+
+from . import ttk
 from .tkwidget import MfxDialog
-from .tkwidget import PysolScale, PysolCombo
-
-if sys.version_info > (3,):
-    basestring = str
-
-# ************************************************************************
-# *
-# ************************************************************************
+from .tkwidget import PysolCombo, PysolScale
 
 
 class WizardDialog(MfxDialog):
@@ -60,7 +49,7 @@ class WizardDialog(MfxDialog):
         notebook.pack(expand=True, fill='both')
 
         for w in WizardWidgets:
-            if isinstance(w, basestring):
+            if isinstance(w, six.string_types):
                 frame = ttk.Frame(notebook)
                 notebook.add(frame, text=w, sticky='nsew', padding=5)
                 frame.columnconfigure(1, weight=1)
@@ -139,7 +128,7 @@ class WizardDialog(MfxDialog):
         n = w.translation_map[n]
         p = presets[n]
         for w in WizardWidgets:
-            if isinstance(w, basestring):
+            if isinstance(w, six.string_types):
                 continue
             if w.var_name in p:
                 v = p[w.var_name]
